==> showimg_0.7.orig.tar.gz: showimg-0.7.orig/showimg/history_action.cpp <==
#include "history_action.h"

#include <qfileinfo.h>
#include <qpopupmenu.h>
#include <kstringhandler.h>
#include <ktoolbar.h>
#include <kiconloader.h>

HistoryAction::HistoryAction( const QString& text, const QString& icon, int accel, 
				const QObject* receiver, const char* slot, QObject* parent, const char* name = 0 )
: KAction( text, icon, accel, receiver, slot, parent, name )
{
	m_popup = 0;
}

HistoryAction::~HistoryAction()
{
	if ( m_popup )
		delete m_popup;
}

int HistoryAction::plug( QWidget *widget, int index )
{
	KToolBar *bar = (KToolBar *)widget;

	int id_ = KAction::getToolButtonID();
	bar->insertButton( icon(), id_, SIGNAL( clicked() ), this,
			   SLOT( slotActivated() ), isEnabled(), plainText(),
			   index );

	addContainer( bar, id_ );
	connect( bar, SIGNAL( destroyed() ), this, SLOT( slotDestroyed() ) );
	bar->setDelayedPopup( id_, popupMenu(), true );
	return containerCount() - 1;
}

void HistoryAction::unplug( QWidget *widget )
{
	KToolBar *bar = (KToolBar *)widget;
	int idx = findContainer( bar );
	if ( idx != -1 )
	{
		bar->removeItem( menuId( idx ) );
		removeContainer( idx );
	}
}

void HistoryAction::fillHistoryPopup( const HistoryEntryList& history,
                                          QPopupMenu * popup,
                                          bool onlyBack,
                                          bool onlyForward,
                                          uint startPos )
{
	QListIterator<HistoryEntry> it( history );
	if (onlyBack || onlyForward) 
	{
		it += history.at(); // Jump to current item
		if ( !onlyForward )
			--it;
		else
			++it; // And move off it
	} 
	else
	if ( startPos )
		it += startPos; // Jump to specified start pos

	uint i = 0;
	while ( it.current() ) 
	{
		QString text = QString("%1").arg(it.current()->filePath);
		text = KStringHandler::csqueeze(text, 50);
		popup->insertItem( BarIcon("folder",16), text );
		if ( ++i > 10 )
			break;
		if ( !onlyForward )
			--it;
		else
			++it;
	}
}

void HistoryAction::setEnabled( bool b )
{
	int len = containerCount();
	for ( int i = 0; i < len; i++ )
	{
		QWidget *w = container( i );
		if ( w->inherits( "KToolBar" ) )
		  ((KToolBar *)w)->setItemEnabled( menuId( i ), b );
	}
	KAction::setEnabled( b );
}

void HistoryAction::setIconSet( const QIconSet& iconSet )
{
	int len = containerCount();
	for ( int i = 0; i < len; i++ )
	{
		QWidget *w = container( i );

		if ( w->inherits( "KToolBar" ) )
			((KToolBar *)w)->setButtonPixmap( menuId( i ), iconSet.pixmap() );

	}
	KAction::setIconSet( iconSet );
}

QPopupMenu *HistoryAction::popupMenu()
{
	if ( m_popup )
		return m_popup;

	m_popup = new QPopupMenu();
	return m_popup;
}

==> showimg_0.9.1.orig.tar.gz: showimg-0.9.1/showimg/history_action.cpp <==
/***************************************************************************
                         history_action.cpp  -  description
                             -------------------
    begin                : 2000
    copyright            : (C) 2000 by Simon Hausmann 
    email                : hausmann@kde.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "history_action.h"

#include <qfileinfo.h>
#include <qpopupmenu.h>

#include <kstringhandler.h>
#include <ktoolbar.h>
#include <kiconloader.h>
#include <kaction.h>

HistoryAction::HistoryAction( const QString& text, const QString& icon, int accel, 
				const QObject* receiver, const char* slot, QObject* parent, const char* name )
: KAction( text, icon, accel, receiver, slot, parent, name )
{
	m_popup = 0;
}

HistoryAction::~HistoryAction()
{
	if ( m_popup )
		delete m_popup;
}

int HistoryAction::plug( QWidget *widget, int index )
{
	KToolBar *bar = (KToolBar *)widget;

	int id_ = KAction::getToolButtonID();
	bar->insertButton( icon(), id_, SIGNAL( clicked() ), this,
			   SLOT( slotActivated() ), isEnabled(), plainText(),
			   index );

	addContainer( bar, id_ );
	connect( bar, SIGNAL( destroyed() ), this, SLOT( slotDestroyed() ) );
	bar->setDelayedPopup( id_, popupMenu(), true );
	return containerCount() - 1;
}

void HistoryAction::unplug( QWidget *widget )
{
	KToolBar *bar = (KToolBar *)widget;
	int idx = findContainer( bar );
	if ( idx != -1 )
	{
		bar->removeItem( itemId( idx ) );
		removeContainer( idx );
	}
}

void HistoryAction::fillHistoryPopup( const HistoryEntryList& history,
                                          QPopupMenu * popup,
                                          bool onlyBack,
                                          bool onlyForward,
                                          uint startPos )
{
	QPtrListIterator<HistoryEntry> it( history );
	if (onlyBack || onlyForward) 
	{
		it += history.at(); // Jump to current item
		if ( !onlyForward )
			--it;
		else
			++it; // And move off it
	} 
	else
	if ( startPos )
		it += startPos; // Jump to specified start pos

	uint i = 0;
	while ( it.current() ) 
	{
		QString text = QString("%1").arg(it.current()->filePath);
		text = KStringHandler::csqueeze(text, 50);
		popup->insertItem( BarIcon("folder",16), text );
		if ( ++i > 10 )
			break;
		if ( !onlyForward )
			--it;
		else
			++it;
	}
}

void HistoryAction::setEnabled( bool b )
{
	int len = containerCount();
	for ( int i = 0; i < len; i++ )
	{
		QWidget *w = container( i );
		if ( w->inherits( "KToolBar" ) )
		  ((KToolBar *)w)->setItemEnabled( itemId( i ), b );
	}
	KAction::setEnabled( b );
}

void HistoryAction::setIconSet( const QIconSet& iconSet )
{
	int len = containerCount();
	for ( int i = 0; i < len; i++ )
	{
		QWidget *w = container( i );

		if ( w->inherits( "KToolBar" ) )
			((KToolBar *)w)->setButtonPixmap( itemId( i ), iconSet.pixmap() );

	}
	KAction::setIconSet( iconSet );
}

QPopupMenu *HistoryAction::popupMenu()
{
	if ( m_popup )
		return m_popup;

	m_popup = new QPopupMenu();
	return m_popup;
}

#include "history_action.moc"
